@@ -51,6 +51,44 @@ build() {
   hello=world make something
 }
 
+package() {
+  cd "${srcdir}"/${pkgname}-${pkgver}
+  make DESTDIR="${pkgdir}" install
+}
+"""
+	# now a more tricky example
+	pkgbuild2 = """
+# Maintainer: Arch Linux <archlinux@example.com>
+# Contributor: Arch Linux <archlinux@example.com>
+
+pkgname=mypackage
+pkgver=1.0
+pkgrel=1
+pkgdesc="A pac
+kage=1 package"
+arch=('i686' 'x86_64')
+url="http://www.example.com/"
+license=('GPL')
+depends=('glibc')
+depends+=('glib2'
+glibc=2.12
+)
+optdepends=('gtk2')
+options=('!libtool')
+source=(ftp://ftp.example.com/pub/mypackage-0.1.tar.gz)
+md5sums=('abcdefabcdef12345678901234567890')
+
+build() {
+  cd "${srcdir}"/${pkgname}-${pkgver}
+  ./configure --prefix=/usr \\
+	--libdir=something
+  _variable=value make; mycustomvar="something"
+  hello=world make something
+  echo 's/a/b/
+        b=c
+        s/c=d/'
+}
+
 package() {
   cd "${srcdir}"/${pkgname}-${pkgver}
   make DESTDIR="${pkgdir}" install
@@ -72,4 +110,15 @@ package() {
 		]))
 		self.assertEqual(r.infos, [])
 
+	def test_example2(self):
+		"a tricky PKGBUILD with custom variables without underscore"
+		r = self.run_on_pkg(self.pkgbuild2)
+		self.assertEqual(r.errors, [])
+		self.assertEqual(set(r.warnings), set([
+			("extra-var-begins-without-underscore %s", "mycustomvar"),
+			("extra-var-begins-without-underscore %s", "hello")
+		]))
+		self.assertEqual(r.infos, [])
+
+
 # vim: set ts=4 sw=4 noet:
